# iCalTV installation by Henrik Nyh <http://henrik.nyh.se> 2006-09-02
#
# Sets you up the bomb.

require "ftools"

class AppleScript
	def initialize(*args)
		@args = args
	end
	def self.timeless(*args)  # TODO: Otestad
		args = ['with timeout of 9999 seconds'] + args + ["end timeout"]
		self.new(*args)
	end
	def self.info(text)
		'display dialog "'+text.to_s+'" with icon note buttons {"OK"}'
	end
	def run
		a = @args.map {|arg| "-e '#{arg}'" }.join(' ')
		`osascript #{a}`
	end
end


# libxml?

begin
	require "rubygems"
	require "xml/libxml"
rescue LoadError => foo  # No libxml
	AppleScript.new(
	'with timeout of 9999 seconds',
		'tell app "iCalTV"',
			'activate',
			'set chosenButton to display dialog "Du verkar inte ha Ruby-biblioteket libxml installerat. Om du installerar det (ngot tekniskt) kommer iCalTV g betydligt snabbare." with icon note buttons {"Visa instruktioner", "Installera ej"} default button "Visa instruktioner"',
			'set choice to button returned of chosenButton',
			'if choice = "Visa instruktioner"',
				'do shell script "open \\"http://docs.rubygems.org/read/chapter/3#page13\\"; open \\"http://libxml.rubyforge.org/install.html\\""',
				'activate',
				AppleScript::info("Enklaste installationsfrfarandet r att installera RubyGems, och sedan libxml genom RubyGems. Instruktioner fr respektive installation har ppnats i din webblsare.\n\nTryck OK nr du installerat libxml eller om du vill fortstta nd."),
			'end if',
		'end tell',
	'end timeout'
	).run
end


SCRIPT_DIR = File.dirname(File.expand_path($0)) unless defined? SCRIPT_DIR
require "#{SCRIPT_DIR}/configuration.rb"


# Create files and directories if necessary

File.makedirs(SERVER_DIR, SCHEDULE_DIR, LOGO_DIR, FAVORITE_DIR, SOUND_DIR, ICAL_TEMPLATE_DIR, ICAL_SCRIPT_DIR)

[CHANNELS_FILE, FAVORITES_FILE, ALERT_FILE].each do |file|
	next if File.exist? file
	File.copy("#{SCRIPT_TEMPLATE_DIR}/#{File.basename(file)}", file)
end

# Copy script templates

Dir.foreach(SCRIPT_SCRIPT_DIR) do |filename|
	startpath = "#{SCRIPT_SCRIPT_DIR}/#{filename}"
	endpath = "#{ICAL_TEMPLATE_DIR}/#{filename}"
	next if filename[0,1] == "." or File.exist?(endpath)
	File.copy(startpath, endpath)
end


# Prompt user to edit files

AppleScript.new(
	'with timeout of 9999 seconds',
		'tell app "Finder"',
			"reveal POSIX file \"#{CHANNELS_FILE}\"",
			'activate',
		'end tell',
		'tell app "iCalTV"',
			'activate',
			AppleScript::info("Innan konfigurationen fortstter br du redigera #{CHANNELS_FILE} och #{FAVORITES_FILE} enligt medfljande README-fil.\n\nEtt Finder-fnster med filerna har ppnats i bakgrunden.\n\nTryck OK nr detta r gjort, fr att fortstta."),
			AppleScript::info("Tabler kommer laddas ner och hndelser skrivas till iCal. Detta kan ta ett tiotal sekunder.\n\nTryck OK fr att brja."),
		'end tell',
	'end timeout'
).run

# Run script

catch :wont_ical do
	require "#{SCRIPT_DIR}/icaltv.rb"
end


# Modify the crontab

crontab = `crontab -l 2>/dev/null`.split("\n")
crontab.reject! {|job| job.include? "iCalTV"}  # remove old iCalTV tasks
ruby = `test -e /usr/local/bin/ruby && echo -n /usr/local/bin/ruby || echo -n ruby`  # fake PATH
crontab << "*/15 * * * * #{ruby} -s #{SCRIPT_DIR}/icaltv.rb -cron"
IO.popen("crontab -", "w") { |out| out.puts crontab.join("\n") }  # write


# iCal info

AppleScript.new(
	'with timeout of 9999 seconds',
		'tell app "iCalTV"',
			'activate',
			AppleScript::info("Nu r allt klart. Nr du trycker OK kommer installationsprocessen avslutas.\n\nProgrammet kommer skta sina uppgifter automatiskt. Om du tar bort eller flyttar programmet slutar iCalTV funka - ls mer i README-filen. Kalendern iCalTV br inte redigeras manuellt."),
		'end tell',
	'end timeout'
).run